
##creating a new S3 class
setClass("tmap", representation("list"))

##a constructor for the object
#' @export
new_tmap = function(obj=NULL,
                      ...
){
  output = list()
  
  ##put data from obj into output
  if(!is.null(obj) & is.list(obj)){
    for(n in names(obj)){
      if(!is.null(output[[n]])){
        warning("Parameter '",n,"' defined more than once. Overwriting parameter provided in obj")
      }else{
        output[[n]] = obj[[n]]
      }
    }
  }
  ##put data from other parameters into output
  if(length(list(...))>0){
    obj = list(...)
    for(n in names(obj)){
      if(!is.null(output[[n]])){
        warning("Parameter '",n,"' defined more than once. Overwriting parameter provided in obj")
      }
      output[[n]] = obj[[n]]
    }    
  }
  
  ##check that requried fields are there, and that all the fields are allowed.
  reqField = c("markerVals","sourceFile")
  optField = c("runParams","tSNE.map","landmarks","clustInfo")
  if(!any(reqField %in% names(output))){
    stop("Missing required fields: ",paste(reqField[!(reqField %in% names(output))],collapse=", "))
  }
  if(!all(names(output) %in% c(reqField,optField))){
    stop("Field not used: ",paste(names(output)[!(names(output) %in% c(reqField,optField))],collapse=", "))
  }
  
  return(new("tmap", output))
}


##override the normal "print" function for tmap
setGeneric("print", function(x) standardGeneric("print"))

#' Default S3 print method for class tmap
#' 
#' @export
setMethod("print", "tmap", definition = 
  function(x,...){
    for(n in names(x)){
      cat("\n$",n,"\n")
      if(n %in% c("markerVals", "tSNE.map")){
        cat("[",nrow(x[[n]]),"Points x",ncol(x[[n]]),"dimensions ]\n")
        
        ##going the long way about this to preserve the colnames of path.PDF
        
        print(head(as.matrix(x[[n]][,1:min(ncol(x[[n]]),5),drop=F])))
        cat("...")
      }
      else if(n %in% "runParams"){
        for(rp_n in names(x[[n]]))
          cat(rp_n,"-",x[[n]][[rp_n]],"\n")
      }
      else{
        if(length(x[[n]])>30){
          cat("[",length(x[[n]]),"Entries ]\n")
          print(head(x[[n]]))
        }else{
          print(x[[n]])
        }
      }
    }
    invisible(x)
  }
)

setMethod("head", "tmap", definition = 
  function(x, ...){invisible(print(x))}
)


##calling 'dim' on a tmap will return the dimensions of the tSNE map (if defined)
## or 
setMethod("dim", "tmap", definition = 
  function(x){
    if(!is.null(x$tSNE.map)){return(dim(x$tSNE.map))}
    return(c(nrow(x$markerVals),NA))
  }
)

#' Default S3 plot method for class tmap
#' 
#' @export
setMethod("plot", "tmap", definition = 
  function(x,...){
    if(is.null(x$tSNE.map)){stop("tSNE.map not defined.")}
    hexplot(x,...)
  }
)
