### R code from vignette source 'adjClust.Rnw'

###################################################
### code chunk number 1: setup
###################################################
options(width=75)
options(SweaveHooks=list(fig=function()
             par(mar=c(5.1, 4.1, 1.1, 2.1))))
library(adjClust)


###################################################
### code chunk number 2: installDependencies (eval = FALSE)
###################################################
## install.packages(c("gplots","hexbin","parallel","png"))
## source("https://bioconductor.org/biocLite.R")
## biocLite(c("cytofkit", "flowCore"))


###################################################
### code chunk number 3: installBuildDependencies (eval = FALSE)
###################################################
## install.packages(c("devtools", "roxygen2", "testthat", "knitr", "rmarkdown"))


###################################################
### code chunk number 4: compileTSNE (eval = FALSE)
###################################################
## compileTSNE()


###################################################
### code chunk number 5: compileTSNE_openMP (eval = FALSE)
###################################################
## compileTSNE(use_omp=TRUE)


###################################################
### code chunk number 6: compileTSNE_MAC
###################################################
compileTSNE(compiler = "g++-4.9", use_omp = T)


###################################################
### code chunk number 7: folder
###################################################
fcsFolder = "~/fcsFiles"

##read all the filenames into a vector
fcsFiles = dir(fcsFolder, full.names = T)

fcsFiles


###################################################
### code chunk number 8: readFCS
###################################################
library(flowCore)

fcsDat = lapply(fcsFiles,function(fn){read.FCS(fn)})


###################################################
### code chunk number 9: getExpr
###################################################
fcsMats = lapply(fcsDat, function(fcs){
  #get marker vals
  eset = exprs(fcs)
  
  ##replace channel names with marker names
  channels = fcs@parameters@data$desc
  names(channels) = colnames(eset)
  channels[is.na(channels)] = colnames(eset)[is.na(channels)]
  colnames(eset) = channels
  
  return(eset)
})

fcsMats[[1]][1:10,1:6]


###################################################
### code chunk number 10: adjClust.Rnw:148-149
###################################################
rm(fcsDat)


###################################################
### code chunk number 11: fcsMatSizes
###################################################
##the number of cells
sapply(fcsMats, nrow)

##the columns in each matrix
sapply(fcsMats, colnames)[1:10,1:4]


###################################################
### code chunk number 12: fcsSubsample
###################################################
##maximum number of cells in each matrix
maxCell = 10000

##subsample each matrix
fcsSubsample = lapply(fcsMats, function(mat){
  #pick which rows to keep
  i = sample(1:nrow(mat), min(nrow(mat), maxCell))
  #return those rows
  mat[i,]
})



###################################################
### code chunk number 13: fcsCombine
###################################################
combinedEset = do.call(rbind, fcsSubsample)

dim(combinedEset)


###################################################
### code chunk number 14: selectMarkers
###################################################
markers = c("CD57","IL8","CD45RO","perforin","TNF","CD25","MIP1b","CD103",
            "CD107ab","CD27","CD45RA","CXCR5","CD28","CD38","CD69","TGFb",
            "IL2","IFNg","IntB7","CCR7","HLA-DR","CD40L","PD-1","CD127")

combinedEset = combinedEset[,markers]


###################################################
### code chunk number 15: asinhTransform
###################################################
combinedEset = apply(combinedEset, 2, arcsinhTransform())


###################################################
### code chunk number 16: fileSource
###################################################
##calculate number of cells from each file
cellCounts = sapply(fcsSubsample, nrow)
##make vector indicating source file for each cell
sourceFile = rep(basename(fcsFiles), times=cellCounts)
#store this in the rownames of combinedEset
rownames(combinedEset) = sourceFile

combinedEset[1:10, 1:4]


###################################################
### code chunk number 17: outFolder
###################################################
outFolder = "~/tsneRun"


###################################################
### code chunk number 18: saveTSNEdat (eval = FALSE)
###################################################
## saveTSNEdat(combinedEset, outFolder)


###################################################
### code chunk number 19: runTSNEinR (eval = FALSE)
###################################################
## runTSNE(outFolder)


###################################################
### code chunk number 20: runTSNEcmd
###################################################
runTSNE(outFolder, commandOnly=T)


###################################################
### code chunk number 21: loadTSNEdat
###################################################
tmap = loadTSNEdat(outFolder)


###################################################
### code chunk number 22: hexplotCodeSimple (eval = FALSE)
###################################################
## plot(tmap)


###################################################
### code chunk number 23: hexplotSimple
###################################################
getOption("SweaveHooks")[["fig"]]()
plot(tmap, xbins=75)


###################################################
### code chunk number 24: plotMarkersCode (eval = FALSE)
###################################################
## plotMarkers(tmap, markerList=c("CD69"))


###################################################
### code chunk number 25: plotMarkers
###################################################
getOption("SweaveHooks")[["fig"]]()
plotMarkers(tmap, markerList=c("CD69"), xbins=80)


###################################################
### code chunk number 26: hidden_metadata
###################################################
fileInfo = data.frame(fn = c("set1.poolA.1172.wk104.ns.CD8T.fcs", "set1.poolA.1172.wk104.pi.CD8T.fcs","set1.poolA.1172.wk18.ns.CD8T.fcs", "set1.poolA.1172.wk18.pi.CD8T.fcs", "set1.poolA.1172.wk40.ns.CD8T.fcs", "set1.poolA.1172.wk40.pi.CD8T.fcs", "set1.poolA.1172.wk53.ns.CD8T.fcs", "set1.poolA.1172.wk53.pi.CD8T.fcs", "set1.poolA.ctrl1.NA.ns.CD8T.fcs", "set1.poolA.ctrl1.NA.pi.CD8T.fcs"),
                      stim=c("ns","pi","ns","pi","ns","pi","ns","pi","ns","pi"),
                      week=c(104,104,18,18,40,40,53,53,NA,NA),
                      donor=c("1172","1172","1172","1172","1172","1172","1172","1172","ctrl","ctrl")
                     )


###################################################
### code chunk number 27: show_metadata
###################################################
fileInfo


###################################################
### code chunk number 28: plotGroupsCode (eval = FALSE)
###################################################
## grp.info = fileInfo[,c("fn","stim")]
## plotGroups(tmap, grp.info = grp.info)


###################################################
### code chunk number 29: plotGroups
###################################################
getOption("SweaveHooks")[["fig"]]()
grp.info = fileInfo[,c("fn","stim")]
plotGroups(tmap, grp.info = grp.info,pctMax =0.002)


###################################################
### code chunk number 30: plotGroupsFormulaCode (eval = FALSE)
###################################################
## plotGroups(fn~donor+stim, data = fileInfo, tmap = tmap)


###################################################
### code chunk number 31: plotGroupsFormula
###################################################
getOption("SweaveHooks")[["fig"]]()
plotGroups(fn~donor+stim, data = fileInfo, tmap = tmap, pctMax=0.0015)


###################################################
### code chunk number 32: cluster_basic
###################################################
tmap = cluster.tmap(tmap, nclust = 20)


###################################################
### code chunk number 33: plotClustersCode (eval = FALSE)
###################################################
## plotClusters(tmap)


###################################################
### code chunk number 34: plotClusters
###################################################
getOption("SweaveHooks")[["fig"]]()
plotClusters(tmap)


###################################################
### code chunk number 35: plotMarkersWithClust_Code (eval = FALSE)
###################################################
## plotMarkers(tmap, markerList = c("CD69","CD27","MIP1b","IL2"))


###################################################
### code chunk number 36: plotMarkersWithClust
###################################################
getOption("SweaveHooks")[["fig"]]()
plotMarkers(tmap, markerList = c("CD69","CD27","MIP1b","IL2"),xbins=75)


###################################################
### code chunk number 37: cluster_complex
###################################################
markerWt = c(MIP1b=0.75, CD27=1.5, IL2=1.5, IntB7=0.75, 
             CXCR5=0.5, CD25=0.5, CD107ab=0.5, CD69=1.25, 
             IFNg=1.3, CD28=0.75, IL8=1.25,perforin=1.2)

tmap = cluster.tmap(tmap, nclust = 15, markerWt = markerWt)


###################################################
### code chunk number 38: plotClusters_take2_code (eval = FALSE)
###################################################
## plotClusters(tmap)


###################################################
### code chunk number 39: plotClusters_take2
###################################################
getOption("SweaveHooks")[["fig"]]()
plotClusters(tmap)


###################################################
### code chunk number 40: clusterReport
###################################################
report = clusterReport(tmap)


###################################################
### code chunk number 41: clusterReport_view
###################################################
report[[8]]


###################################################
### code chunk number 42: clusterReport_clust14
###################################################
report[[14]]


###################################################
### code chunk number 43: clusterReport_10alpha
###################################################
report = clusterReport(tmap, alpha = 0.1)
report[[14]]


###################################################
### code chunk number 44: showGrpInfo_again
###################################################
head(grp.info)


###################################################
### code chunk number 45: compareGroups
###################################################
cmpInfo = compareGroups(tmap, grp.info = grp.info, contrast = "pi-ns")
head(cmpInfo)


###################################################
### code chunk number 46: compareGroups_formula
###################################################
cmpInfo = compareGroups(fn~donor+stim, data = fileInfo, 
                        contrast = "1172_pi-1172_ns", tmap = tmap)
head(cmpInfo)


###################################################
### code chunk number 47: clusterCounts
###################################################
cts = clusterCounts(tmap)
cts[1:4,1:6]
pct = clusterFract(tmap)
signif(pct[1:4,1:4],3)


