% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/plot_tmap.R
\name{plotMarkers}
\alias{plotMarkers}
\title{Plot matrix of markers}
\usage{
plotMarkers(tmap, markerList = NULL, col.lim = NULL, mfrow = NULL,
  addEdges = !is.null(tmap$binInfo), xbins = 100, min.grp = 5,
  rasterize = (names(dev.cur()) == "pdf"), col.fn = NULL, colKey = NULL,
  ...)
}
\arguments{
\item{tmap}{the tmap object to be plotted}

\item{markerList}{list of markers to be included in the plot. If null, all markers 
will be plotted.}

\item{col.lim}{vector of length 2; describes the minimum and maximum values used 
when calculating the color range. Values outside this range will
be set to the closest color inside the range, as appropirate. If 
null, col.lim is set to \code{range(tmap$markerVals)}.}

\item{mfrow}{vector of length 2, to be passed on to par. Determines number of 
rows/columns to include in each plot. If not supplied, an 
appropriate mfrow will be determined automatically.}

\item{xbins}{number of bins that divide the x axis. See hexplot for details}

\item{min.grp}{minimum bin size for grouping points. See hexplot for details}

\item{rasterize}{boolean; should the image be rasterized (converted to png before 
plotting)? Useful to reduce file size when plotting to pdf 
(or other vector-based device).}

\item{col.fn}{a colorRamp function which takes values from 0 to 1 and returns 
RGB specifications. Default is a colorRamp from Green -> Black -> Red.}

\item{colKey}{named vector indicating the values for the color key}

\item{...}{additional parameters to be passed to hexplot}
}
\description{
Generate hexplot maps for expression of a set of markers
}
\details{
The \code{plotMarkers} function creates a matrix of hexplots, colored by the expression
of the markers in \code{tmap$markerVals}. The colors are determined using a 
\code{\link[RColorBrewer]{colorRamp}} function from the \code{RColorBrewer} package, 
which can be specified via the '\code{col.fn}' parameter (see 
\code{\link[RColorBrewer]{colorRamp}} for details on supplying alternative color fns). 
By default, colors will range from green (lowest value) to red (highest value), with 
the lowest and highest values defined by \code{col.lim}. Any values outside the range of 
\code{col.lim} will be displayed as either completely red or completely green.

If \code{rasterize} is \code{TRUE}, each individual plot will be converted to a raster
image and plotted using the \code{rasterImage} function. This is especially important
if the plots are being saved to a vector-based format, such as a pdf, because the large
number of individual points in each graph will make the pdf file impractically large.
}

